@@ -104,7 +104,8 @@ class ClientArgsCreator(object):
             proxies=new_config.proxies,
             timeout=(new_config.connect_timeout, new_config.read_timeout),
             socket_options=socket_options,
-            client_cert=new_config.client_cert)
+            client_cert=new_config.client_cert,
+            proxies_config=new_config.proxies_config)
 
         serializer = botocore.serialize.create_serializer(
             protocol, parameter_validation)
@@ -165,6 +166,7 @@ class ClientArgsCreator(object):
                 read_timeout=client_config.read_timeout,
                 max_pool_connections=client_config.max_pool_connections,
                 proxies=client_config.proxies,
+                proxies_config=client_config.proxies_config,
                 retries=client_config.retries,
                 client_cert=client_config.client_cert,
                 inject_host_prefix=client_config.inject_host_prefix,
